@@ -18,6 +18,7 @@ from testflows._core.cli.arg.handlers.handler import Handler as HandlerBase
 from testflows._core.cli.arg.handlers.show.passing import Handler as passing_handler
 from testflows._core.cli.arg.handlers.show.totals import Handler as totals_handler
 from testflows._core.cli.arg.handlers.show.fails import Handler as fails_handler
+from testflows._core.cli.arg.handlers.show.unstable import Handler as unstable_handler
 from testflows._core.cli.arg.handlers.show.version import Handler as version_handler
 from testflows._core.cli.arg.handlers.show.coverage import Handler as coverage_handler
 from testflows._core.cli.arg.handlers.show.results import Handler as results_handler
@@ -48,6 +49,7 @@ class Handler(HandlerBase):
         results_handler.add_command(show_commands)
         passing_handler.add_command(show_commands)
         fails_handler.add_command(show_commands)
+        unstable_handler.add_command(show_commands)
         totals_handler.add_command(show_commands)
         coverage_handler.add_command(show_commands)
         version_handler.add_command(show_commands)
@@ -63,4 +65,4 @@ class Handler(HandlerBase):
         metrics_handler.add_command(show_commands)
         examples_handler.add_command(show_commands)
         specifications_handler.add_command(show_commands)
-        result_handler.add_command(show_commands)
\ No newline at end of file
+        result_handler.add_command(show_commands)
