@@ -1,5 +1,5 @@
 # Copyright 2019 Katteli Inc.
-# TestFlows Test Framework (http://testflows.com)
+# TestFlows.com Open-Source Software Testing Framework (http://testflows.com)
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,8 +24,8 @@ class TestFlowsLexer(RegexLexer):
 
     tokens = {
         'root': [
-            (r'(\s*)(Module|Suite|Feature|Test|Scenario)( .*)', bygroups(Keyword, Keyword.Namespace, Name.Namespace)),
-            (r'(\s*)(Given|When|Then|And|By|Finally)', Keyword),
+            (r'(\s*)(Module|Suite|Feature|Test|Scenario|Example|Outline)( .*)', bygroups(Keyword, Keyword.Namespace, Name.Namespace)),
+            (r'(\s*)(Step|Background|Given|When|Then|But|And|By|Finally)', Keyword),
             (r'(\s*)(Arguments|Requirements|Attributes|Tags|Examples)', Name.Label),
             (r'(\s*)OK', Result.OK),
             (r'(\s*)Fail', Result.Fail),
@@ -35,4 +35,4 @@ class TestFlowsLexer(RegexLexer):
             (r'(\s*)(XOK|XFail|XNull|XError)', Result.Xout),
             (r' .*\n', Text),
         ]
-    }
\ No newline at end of file
+    }
